==> Ambidexterity-0.2.0%2B1.21.5-Fabric-sources.jar: eva/ambidexterity/mixin/InventoryMenuMixin.java <==
package eva.ambidexterity.mixin;

import com.llamalad7.mixinextras.sugar.Local;
import net.minecraft.class_1723;
import net.minecraft.class_1735;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.injection.*;

@Mixin(class_1723.class)
public class InventoryMenuMixin {

//    @ModifyArg(
//            method = "<init>",
//            at = @At(
//                    value = "INVOKE",
//                    target = "Lnet/minecraft/world/inventory/InventoryMenu;addStandardInventorySlots(Lnet/minecraft/world/Container;II)V"
//            ),
//            index = 1
//    )
//    private int shiftSlots(int par2) {
//        return 6;
//    }

    @Redirect(
            method = "<init>",
            at = @At(
                    value = "INVOKE",
                    target = "Lnet/minecraft/world/inventory/InventoryMenu;addSlot(Lnet/minecraft/world/inventory/Slot;)Lnet/minecraft/world/inventory/Slot;",
                    ordinal = 1
            )
    )
    private class_1735 noOffhand(class_1723 instance, class_1735 slot) {
        return slot;
    }

//    @ModifyConstant(
//            method = "<init>",
//            constant = @Constant(intValue = 39)
//    )
//    private int shiftEquipmentSlots(int constant, @Local EquipmentSlot slot) {
//        return 43;
//    }

//    @ModifyConstant(
//            method = "quickMoveStack",
//            constant = @Constant(intValue = 9)
//    )
//    private int hotbarIs10(int constant) {
//        return 10;
//    }
}

==> Ambidexterity-0.3.0%2B1.21.1-Fabric-sources.jar: eva/ambidexterity/mixin/InventoryMenuMixin.java <==
package eva.ambidexterity.mixin;

import net.minecraft.class_1723;
import net.minecraft.class_1735;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.injection.At;
import org.spongepowered.asm.mixin.injection.Redirect;

@Mixin(class_1723.class)
public class InventoryMenuMixin {

//    @ModifyArg(
//            method = "<init>",
//            at = @At(
//                    value = "INVOKE",
//                    target = "Lnet/minecraft/world/inventory/InventoryMenu;addStandardInventorySlots(Lnet/minecraft/world/Container;II)V"
//            ),
//            index = 1
//    )
//    private int shiftSlots(int par2) {
//        return 6;
//    }

    @Redirect(
            method = "<init>",
            at = @At(
                    value = "INVOKE",
                    target = "Lnet/minecraft/world/inventory/InventoryMenu;addSlot(Lnet/minecraft/world/inventory/Slot;)Lnet/minecraft/world/inventory/Slot;",
                    ordinal = 1
            )
    )
    private class_1735 noOffhand(class_1723 instance, class_1735 slot) {
        return slot;
    }

//    @ModifyConstant(
//            method = "<init>",
//            constant = @Constant(intValue = 39)
//    )
//    private int shiftEquipmentSlots(int constant, @Local EquipmentSlot slot) {
//        return 43;
//    }

//    @ModifyConstant(
//            method = "quickMoveStack",
//            constant = @Constant(intValue = 9)
//    )
//    private int hotbarIs10(int constant) {
//        return 10;
//    }
}
